const extToRegexp = require('ext-to-regexp');

const displayName = 'babel';

exports.name = displayName;

exports.apply = function applyBabel({
  config: { 'if-else': ifElse },
  mode = 'production',
  browsers
}) {
  return chain => {
    chain.module
      .rule(displayName)
      .test(extToRegexp('js', 'mjs'))
      .use('babel-loader')
      .loader('babel-loader')
      .options({
        sourceType: 'unambiguous',
        cacheDirectory: mode === 'development',
        compact: mode === 'production',
        presets: [
          [
            '@babel/env',
            {
              modules: false,
              targets: { browsers }
            }
          ]
        ],
        plugins: [
          '@babel/syntax-dynamic-import',
          '@babel/proposal-export-namespace-from',
          '@babel/proposal-numeric-separator',
          ['@babel/proposal-decorators', { legacy: true }],
          '@babel/proposal-class-properties'
        ]
      });

    if (ifElse) {
      chain.module.rule(displayName).before('if-else');
    }
  };
};
